==> emodpy-1.1.0-py3-none-any.whl: tests/test_slurm.py <==
import os

import pytest
from idmtools.entities.experiment import Experiment

from idmtools.builders import SimulationBuilder
from idmtools.core.platform_factory import Platform
from idmtools.entities.templated_simulation import TemplatedSimulations
from idmtools_test.utils.itest_with_persistence import ITestWithPersistence

from emodpy.defaults import EMODSir
from emodpy.emod_task import EMODTask
from emodpy.generic.serialization import add_serialization_timesteps
from examples.config_update_parameters import config_update_params

current_directory = os.path.dirname(os.path.realpath(__file__))
BIN_PATH = os.path.join(current_directory, "..", "examples", "inputs", "bin")
INPUT_PATH = os.path.join(current_directory, "..", "examples", "emod_demographics", "inputs")

num_seeds = 2
sim_duration = 3


@pytest.mark.comps
class TestSerialization(ITestWithPersistence):

    def setUp(self) -> None:
        self.case_name = os.path.basename(__file__) + "--" + self._testMethodName
        print(self.case_name)
        self.platform = Platform('SLURM')

    def test_basic_experiment_in_slurm(self):
        task = EMODTask.from_default(default=EMODSir(), eradication_path=os.path.join(BIN_PATH, "Eradication"))
        task.legacy_exe = True

        # Remove default demographic files from EMODSir's config Demographics_Filenames
        task.demographics.clear()
        demo_file = os.path.join(INPUT_PATH, "demographics.json")

        # Add new demographic file from local to experiment level( Assets dir in comps's)
        task.demographics.add_demographics_from_file(demo_file)

        # Update bunch of config parameters
        config_update_params(task)
        task.set_parameter("Config_Name", "test slurm sim")
        task.set_parameter("Enable_Susceptibility_Scaling", 2)

        # Add serialization parameters
        timesteps = [sim_duration * 365]
        add_serialization_timesteps(task=task, timesteps=timesteps,
                                    end_at_final=False, use_absolute_times=False)

        # Create TemplatedSimulations with task
        ts = TemplatedSimulations(base_task=task)

        # Create SimulationBuilder
        builder = SimulationBuilder()
        # Add sweep parameter to builder
        builder.add_sweep_definition(EMODTask.set_parameter_partial("Run_Number"), range(num_seeds))
        # Add another sweep parameter to builder
        builder.add_sweep_definition(EMODTask.set_parameter_partial("Base_Infectivity"), [0.6, 1.0, 1.5, 2.0])

        # Add builder to templated simulations
        ts.add_builder(builder)

        # Create experiment from template
        experiment = Experiment.from_template(ts, name=self.case_name)

        # The last step is to call run() on the ExperimentManager to run the simulations.
        self.platform.run_items(experiment)
        self.platform.wait_till_done(experiment)
        self.assertTrue(experiment.succeeded, "expected experiment succeeded")

==> emodpy-1.3.0-py3-none-any.whl: tests/test_slurm.py <==
import os

import pytest
from idmtools.entities.experiment import Experiment

from idmtools.builders import SimulationBuilder
from idmtools.core.platform_factory import Platform
from idmtools.entities.templated_simulation import TemplatedSimulations
from idmtools_test.utils.itest_with_persistence import ITestWithPersistence

from emodpy.defaults import EMODSir
from emodpy.emod_task import EMODTask
from emodpy.generic.serialization import add_serialization_timesteps
from examples.config_update_parameters import config_update_params

current_directory = os.path.dirname(os.path.realpath(__file__))
BIN_PATH = os.path.join(current_directory, "..", "examples", "inputs", "bin")
INPUT_PATH = os.path.join(current_directory, "..", "examples", "emod_demographics", "inputs")

num_seeds = 2
sim_duration = 3


@pytest.mark.comps
class TestSerialization(ITestWithPersistence):

    def setUp(self) -> None:
        self.case_name = os.path.basename(__file__) + "--" + self._testMethodName
        print(self.case_name)
        self.platform = Platform('SLURM')

    def test_basic_experiment_in_slurm(self):
        task = EMODTask.from_default(default=EMODSir(), eradication_path=os.path.join(BIN_PATH, "Eradication"))
        task.legacy_exe = True

        # Remove default demographic files from EMODSir's config Demographics_Filenames
        task.demographics.clear()
        demo_file = os.path.join(INPUT_PATH, "demographics.json")

        # Add new demographic file from local to experiment level( Assets dir in comps's)
        task.demographics.add_demographics_from_file(demo_file)

        # Update bunch of config parameters
        config_update_params(task)
        task.set_parameter("Config_Name", "test slurm sim")
        task.set_parameter("Enable_Susceptibility_Scaling", 2)

        # Add serialization parameters
        timesteps = [sim_duration * 365]
        add_serialization_timesteps(task=task, timesteps=timesteps,
                                    end_at_final=False, use_absolute_times=False)

        # Create TemplatedSimulations with task
        ts = TemplatedSimulations(base_task=task)

        # Create SimulationBuilder
        builder = SimulationBuilder()
        # Add sweep parameter to builder
        builder.add_sweep_definition(EMODTask.set_parameter_partial("Run_Number"), range(num_seeds))
        # Add another sweep parameter to builder
        builder.add_sweep_definition(EMODTask.set_parameter_partial("Base_Infectivity"), [0.6, 1.0, 1.5, 2.0])

        # Add builder to templated simulations
        ts.add_builder(builder)

        # Create experiment from template
        experiment = Experiment.from_template(ts, name=self.case_name)

        # The last step is to call run_items() on the platform to run the simulations.
        self.platform.run_items(experiment)
        self.platform.wait_till_done(experiment)
        self.assertTrue(experiment.succeeded, "expected experiment succeeded")
